@@ -46,12 +46,15 @@ def create_application(path):
     def home():   
         if request.method=='POST':
             experiment_folder=request.form['experiment']
-            if os.path.exists(f"{path}/{experiment_folder}/notes/table_{experiment_folder}.html"):
+            try:
                 shutil.copy(f"{path}/{experiment_folder}/notes/table_{experiment_folder}.html",f"{current_path}/templates/")
+            except Exception as e:
+                pass
             return redirect(url_for("home2",experiment=experiment_folder))
         
         else:
             folders=os.listdir(path)
+            print(folders)
             return render_template("experiment_page.html",folders=folders)
         
     @app.route('/home2/<experiment>',methods=["POST","GET"])
@@ -71,7 +74,7 @@ def create_application(path):
                 df=df.replace(np.nan,"")
                 html=df.to_html()
                 html=html.replace('<table border="1" class="dataframe">','<table border="1" width="100%" contenteditable=true  class="dataframe" id="table_">')
-                with open(f"{current_path}/templates/table_{experiment}.html", 'w') as f:
+                with open(f"{path}/{experiment}/notes/table_{experiment}.html", 'w') as f:
                     f.write(html)
                 os.remove(latest_file)
             return redirect(url_for("home2",experiment=experiment))
@@ -105,8 +108,11 @@ def create_application(path):
                 pred_file = open(prediction_path, "r")
                 pred_dict=json.load(pred_file)
                 prediction_file_path_exists=True
-            if not os.path.exists(f"{path}/team_notes/notes.txt"):
-                os.mkdir(f"{path}/team_notes/notes.txt")
+            if not os.path.exists(f"{path}/team_notes/"):
+                os.mkdir(f"{path}/team_notes/")
+                text_file = open(f"{path}/team_notes/notes.txt", "w")
+                text_file.write("")
+                text_file.close()
             notes_path=f"{path}/team_notes/notes.txt"
             with open(notes_path) as f:
                 contents = f.read()
